==> image-loader-2.0.6-sources.jar: com/budiyev/android/imageloader/UriDataDescriptor.java <==
/*
 * MIT License
 *
 * Copyright (c) 2017 Yuriy Budiyev [yuriy.budiyev@yandex.ru]
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.budiyev.android.imageloader;

import android.net.Uri;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

final class UriDataDescriptor extends IdentifiableDataDescriptor<Uri> {
    private final boolean mStorageCachingEnabled;

    public UriDataDescriptor(@NonNull Uri data, @Nullable Size requiredSize) {
        super(data, data.toString(), requiredSize);
        mStorageCachingEnabled = !InternalUtils.isUriLocal(data);
    }

    @Override
    public boolean isStorageCachingEnabled() {
        return mStorageCachingEnabled;
    }

    @Override
    public boolean isMemoryCachingEnabled() {
        return true;
    }
}

==> image-loader-2.1.1-sources.jar: com/budiyev/android/imageloader/UriDataDescriptor.java <==
/*
 * MIT License
 *
 * Copyright (c) 2018 Yuriy Budiyev [yuriy.budiyev@yandex.ru]
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.budiyev.android.imageloader;

import android.net.Uri;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

final class UriDataDescriptor extends IdentifiableDataDescriptor<Uri> {
    private final CacheMode mCacheMode;

    public UriDataDescriptor(@NonNull Uri data) {
        super(data, data.toString());
        mCacheMode = InternalUtils.isUriLocal(data) ? CacheMode.MEMORY : CacheMode.FULL;
    }

    @Nullable
    @Override
    public CacheMode getCacheMode() {
        return mCacheMode;
    }
}
